################################################################################
## Initialization
################################################################################

init offset = -2

################################################################################
#
#   This file defines the movement system and instantiates it, as well as
#   defines the class structure to be used for all locations.  Each location
#   has an associated publicity value, and a set of background CGs.
#
################################################################################

init python:

    gtest = 0

    default_location = "room1"

    def buildImageList(name): # builds a dictionary of background images to be associated with the location specified by name
        renpy.image( name+' morning', name+' morning.jpg')
        renpy.image( name+' day', name+' day.jpg')
        renpy.image( name+' evening', name+' evening.jpg')
        renpy.image( name+' night', name+' night.jpg')

    room_list = ['room1','room2','room3']
    [buildImageList for i in room_list]

    class Mapkeeper:

        def __init__(self):
            self.compass = default_location
            self.map_index = []
            self.scene_index =[]

        def addCell(self, name, **kwargs):
            cell_data = {'name'        : name,    # system name to be used with RenPy logic
                         'dname'       : "Forgot display name.",   # displayed name to be used with the user interface
                         'connections' : [],                       # array of locations you can move to from this cell
                         'morning_p'   : 0,                        # publicity rating of this cell in the morning
                         'day_p'       : 0,                        # publicity rating of this cell in the day
                         'evening_p'   : 0,                        # publicity rating of this cell in the evening
                         'night_p'     : 0                         # publicity rating of this cell in the night
                         }
            self.map_index.append(cell_data)
            self.updateCell(name, **kwargs)


        def getCellInfo(self, name='None'):
            if name == 'None':
                name = self.compass
            my_item = next((item for item in self.map_index if item['name'] == name), None)
            return my_item

        def getConnections(self, name='None'): # gets available connections based on the passed cell name, defaults to current cell
            if name == 'None':
                name = self.compass
            cell = self.getCellInfo(name)
            if cell is None:
                connections = []
            else:
                connections = cell['connections']
            return connections

        def getDisplayName(self, name='None'): # gets the display name of the specified cell, defaults to current cell
            if name == 'None':
                name = self.compass
            cell = self.getCellInfo(name)
            if cell is None:
                dname = "Not found"
            else:
                dname = cell['dname']
            return dname

        def getPublicity(self, name='None'):
            if name == 'None':
                name = self.compass
            cell = self.getCellInfo(name)
            if cell is None:
                return 1024
            period = Kronos.getPeriod()
            if period == "Morning":
                publicity = cell['morning_p']
            elif period == "Day":
                publicity = cell['day_p']
            elif period == "Evening":
                publicity = cell['evening_p']
            elif period == "Night":
                publicity = cell['night_p']
            return publicity

        def updateCell(self, name='None', **kwargs): # if you need to alter any cell attribute; for adding and remove cell connections, use the other functions
            if name == 'None':
                name = self.compass
            event = None
            for k in self.map_index:
                if k['name'] == name:
                    event = k
                    break
            if not event:
                gtest = name
                raise Exception # Not found
            for k in kwargs:
                if k == 'name':
                    continue # cannot update system name
                elif k in ['dname', 'connections', 'morning_p', 'day_p', 'evening_p', 'night_p']:
                    event[k] = kwargs[k]
                else:
                    # Unknown keyword
                    raise ValueError('Within class Mapkeeper, within function updateCell, passed an unknown keyword.')

        def removeDuplicate(list): # toolkit to remove duplicates from a list, consider making a toolkit object
            final_list = []
            for string in duplicate:
                if string not in final_list:
                    final_list.append(string)
            return final_list

        def addConnection(self, name='None', *args): # adds connections to the cell specified by name
            if name == 'None':
                name = self.compass
            event = None
            for k in self.map_index:
                if k['name'] == name:
                    event = k
                    break
            if not event:
                raise KeyError # Not found
            for k in args:
                self.map_index[event]['connections'].append(args[k])
            self.removeDuplicate(self.map_index[event]['connections'])

        def removeConnection(self, name='None', *args): # removes connections to the cell specified by name
            if name == 'None':
                name = self.compass
            event = None
            for k in self.map_index:
                if k['name'] == name:
                    event = k
                    break
            if not event:
                raise KeyError # Not found
            for k in args:
                self.map_index[event]['connections'] = [x for x in self.map_index[event]['connections'] if x != args[k]]

        def moveTo(self, toeSuck, *args, **kwargs): # for my boy, CT; toeSuck is the system name of the cell to be moved to
            backdrop = None
            period = Kronos.getPeriod()
            if period == 'Morning':
                renpy.scene()
                renpy.show(toeSuck+' morning')
            elif period == 'Day':
                renpy.scene()
                renpy.show(toeSuck+' day')
            elif period == 'Evening':
                renpy.scene()
                renpy.show(toeSuck+' evening')
            elif period == 'Night':
                renpy.scene()
                renpy.show(toeSuck+' night')
            timepass = self.getConnections(self.compass)
            for m in timepass:
                if m[0] == toeSuck:
                    Kronos.advance(minutes=m[1])
                    break
            self.compass = toeSuck
            renpy.retain_after_load()




label map_fill:

    python:
        Amerigo.addCell(name        ="room1",    # system name to be used with RenPy logic
                        dname       ="Room 1",   # displayed name to be used with the user interface
                        connections =[['room2',10],['room3',15]],                       # array of locations you can move to from this cell
                        morning_p   =1,                        # publicity rating of this cell in the morning
                        day_p       =2,                        # publicity rating of this cell in the day
                        evening_p   =3,                        # publicity rating of this cell in the evening
                        night_p     =4                         # publicity rating of this cell in the night
                        )

        Amerigo.addCell(name        ="room2",    # system name to be used with RenPy logic
                        dname       ="Room 2",   # displayed name to be used with the user interface
                        connections=[['room1',10],['room3',5]],                       # array of locations you can move to from this cell
                        morning_p   =5,                        # publicity rating of this cell in the morning
                        day_p       =6,                        # publicity rating of this cell in the day
                        evening_p   =7,                        # publicity rating of this cell in the evening
                        night_p     =8                         # publicity rating of this cell in the night
                        )

        Amerigo.addCell(name        ="room3",    # system name to be used with RenPy logic
                        dname       ="Room 3",   # displayed name to be used with the user interface
                        connections =[['room1',15],['room2',5]],                       # array of locations you can move to from this cell
                        morning_p   =9,                        # publicity rating of this cell in the morning
                        day_p       =1,                        # publicity rating of this cell in the day
                        evening_p   =2,                        # publicity rating of this cell in the evening
                        night_p     =3                         # publicity rating of this cell in the night
                    )

    return
