################################################################################
## Initialization
################################################################################

init offset = -3

################################################################################
#
#   This file defines the event handler.  This class is responsible for
#   generating events and defining their availability based on the time of day,
#   location, NPC presence, and keystone variable for manual control.  It's important to
#   realize that events and interactions are not the same thing.
#
################################################################################

init python:

    class Schedulekeeper:

        def __init__(self):
            event_index = []

        def addEvent(self, name, **kwargs): # add a new event from scratch
            event_data = {  'name'          : name,
                            'dname'         : 'dname',
                            'locations'     : [],
                            'npc'           : [],
                            'time_of_day'   : [],
                            'day_of_week'   : [],
                            'keystone'      : True
                         }
            self.event_index.append(event_data)
            self.updateEvent(name, **kwargs)

        def updateEvent(self, name='None', **kwargs): # update an existing event
            if name == 'None':
                raise ValueException('updateEvent called without event name')
            event = None
            for k in self.event_index:
                if k['name'] == name:
                    event = k
                    break
            if not event:
                raise Exception # Not found
            for k in kwargs:
                if k == 'name':
                    continue # cannot update system name
                elif k in ['dname', 'locations', 'npc', 'time_of_day', 'day_of_week', 'keystone']:
                    event[k] = kwargs[k]
                else:
                    # Unknown keyword
                    raise ValueError('Within class Schedulekeeper, within function updateEvent, passed an unknown keyword.')

        def getEventInfo(self, name='None'):
            if name == 'None':
                raise ValueException('getEventInfo called without event name')
            my_item = next((item for item in self.event_index if item['name'] == name), None)
            return my_item

        def getEventStatus(self, name='None'): # return a True or False depending on the event's enabling factors
            if name == 'None':
                raise ValueException('getEventStatus called without event name')
            event = self.getEventInfo(name)
            location    = False
            NPC         = False
            Time        = False
            Day         = False
            Key         = False
            for i in event['locations']:
                if i == Amerigo.compass:
                    location = True
            
