################################################################################
## Initialization
################################################################################

init offset = -3

################################################################################
#
#   This file defines and instantiates the time-tracking system of the game.
#   It keeps track of the week, day, hour, and minute.  Getting values for
#   larger time periods is relatively simple, but seems unnecessary.
#
################################################################################


init python:

    class Timekeeper:

        def __init__(self):
            self.minute = 0 # total minute tally for the game, do not directly alter
            self.timescale = 1 # used to represent either the slowing down or speeding up of time

        def getWeek(self):
            week = (self.minute // ( 60*24*7)) + 1 # total number of minutes divided by the number of minutes in a week
            return week

        def getDay(self):
            minute_of_week = self.minute % (60*24*7) # returns the minute count of the current week
            day_of_week = minute_of_week // (60*24) # returns the number of the current day based on the minute count of the current week
            day_name = ""
            if day_of_week == 0:
                day_name = "Sunday"
            elif day_of_week == 1:
                day_name = "Monday"
            elif day_of_week == 2:
                day_name = "Tuesday"
            elif day_of_week == 3:
                day_name = "Wednesday"
            elif day_of_week == 4:
                day_name = "Thursday"
            elif day_of_week == 5:
                day_name = "Friday"
            elif day_of_week == 6:
                day_name = "Saturday"
            return day_name

        def getPeriod(self):
            minute_of_week = self.minute % (60*24*7)
            minute_of_day = minute_of_week % (60*24) # returns the minute count of the current day
            period = ""
            if 240 <= minute_of_day <= 599: # between 04:00 and 09:59
                period = "Morning"
            elif 600 <= minute_of_day <= 959: # between 10:00 and 15:59
                period = "Day"
            elif 960 <= minute_of_day <= 1319: # between 16:00 and 21:59
                period = "Evening"
            elif (minute_of_day <= 239) or (minute_of_day >= 1320): # between 22:00 and 03:59
                period = "Night"
            return period

        def getHour(self):
            minute_of_week = self.minute % (60*24*7)
            minute_of_day = minute_of_week % (60*24) # returns the minute count of the current day
            hour_of_day = minute_of_day // 60 # returns the hour count of the current day
            return str(hour_of_day)

        def getMinute(self):
            minute_of_week = self.minute % (60*24*7)
            minute_of_day = minute_of_week % (60*24) # returns the minute count of the current day
            minute_of_hour = minute_of_day % 60 # returns the minute count of the current hour
            return str(minute_of_hour)

        def getTime(self):
            minute = self.getMinute()
            hour = self.getHour()
            if len(minute) == 1:
                minute = '0' + minute
            if len(hour) == 1:
                hour = '0' + hour
            clock = hour + ':' + minute
            return clock

        def advance(self, minutes=0, hours=0, days=0, weeks=0, **kwargs):
            self.minute += self.timescale*minutes
            self.minute += self.timescale*hours*60
            self.minute += self.timescale*days*60*24
            self.minute += self.timescale*weeks*60*24*7
            return

        def toggleTimestop(self): # logic doesn't account for values other than 0 or 1
            if self.timescale == 1:
                self.timescale = 0
                return
            else:
                self.timescale = 1
                return

        def setTimescale(self, scale):
            self.timescale = scale
            return

        def alarm(self, hour=-1, minute=-1, **kwargs):
            while minute >= 0:
                if self.getMinute() == minute:
                    break
                self.minutes += 1
            while hour >= 0:
                if self.getHour() == hour:
                    break
                self.minutes += 60
            return
